# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from .hs_code_with_description import HsCodeWithDescription
import typing
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TradeTraversalProduct(UniversalBaseModel):
    hs_code: HsCodeWithDescription
    min_date: str
    max_date: str
    arrival_countries: typing.List[str]
    departure_countries: typing.List[str]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
