# This file was auto-generated by Fern from our API Definition.

import typing

SortField = typing.Union[
    typing.Literal[
        "created",
        "-created",
        "saved_resource_id",
        "-saved_resource_id",
        "entity_id",
        "-entity_id",
        "country",
        "-country",
        "latest_status",
        "-latest_status",
        "label",
        "-label",
        "custom_{field name}",
        "-custom_{field name}",
        "receiver_of",
        "-receiver_of",
        "shipper_of",
        "-shipper_of",
        "upstream_entities",
        "-upstream_entities",
    ],
    typing.Any,
]
