# This file was auto-generated by Fern from our API Definition.

from ...core.pydantic_utilities import UniversalBaseModel
from ...generated_types.types.both_identifier_types import BothIdentifierTypes
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class Identifier(UniversalBaseModel):
    """
    Identifiers associated with the entity.
    """

    value: str
    type: BothIdentifierTypes = pydantic.Field()
    """
    [Identifier Type](/sayari-library/ontology/enumerated-types#identifier-type) or [Weak Identifier Type](/sayari-library/ontology/enumerated-types#weak-identifier-type)
    """

    label: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
